@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2023-2024 the Eask authors.
+ * Copyright (C) 2023-2026 the Eask authors.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 "use strict";
 
 exports.command = ['autoloads'];
-exports.desc = 'Remove generated autoloads file';
+exports.desc = 'Remove the generated autoloads file';
 
 exports.handler = async (argv) => {
   await UTIL.e_call(argv, 'clean/autoloads', argv.dest);
