@@ -35,7 +35,7 @@
 
 (eask-start
   (eask-defvc< 27 (eask-pkg-init))  ; XXX: remove this after we drop 26.x
-  (if-let ((names (eask-args)))
+  (if-let* ((names (eask-args)))
       (eask-uninstall--packages names)
     (if-let* ((name (intern (eask-guess-package-name)))
               ((package-installed-p name)))
